@@ -8,7 +8,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-undo-fu-session
 ;; Keywords: convenience
-;; Version: 0.7
+;; Package-Version: 20250918.17
+;; Package-Revision: 366717d88f77
 ;; Package-Requires: ((emacs "28.1"))
 
 ;;; Commentary:
@@ -17,7 +18,7 @@
 ;; individual file buffers persistently.
 ;;
 
-;;; Usage:
+;;; Usage
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -60,9 +61,9 @@
       (gv-letplace (getter setter) place
         (funcall setter `(- ,getter ,(or delta 1)))))))
 
-;; Workaround bug in Emacs 30, where this macro fails to enable
+;; Workaround bug in Emacs 30, where this macro fails when to enable
 ;; auto-compression-mode when a file is loaded from the command line.
-;; The problem seems to be that `auto-compression-mode' is true,
+;; The problem seems to be `auto-compression-mode' is true,
 ;; but the mode has not started when undo-fu-session runs.
 ;; Workaround the bug by replacing the auto-compression-mode
 ;; check with `jka-compr-installed-p'.
@@ -80,7 +81,7 @@
              (unless ,already-installed
                (auto-compression-mode 1))
              ,@body)
-         (unless ,already-installed
+         (unless (or ,already-installed)
            (auto-compression-mode -1))
          ;; Restore the initial state (even if it's inconsistent).
          (setq auto-compression-mode ,already-installed-value)))))
@@ -100,11 +101,11 @@
 (defcustom undo-fu-session-directory
   (locate-user-emacs-file "undo-fu-session" ".emacs-undo-fu-session")
   "The directory to store undo data."
-  :type 'directory)
+  :type 'string)
 
 (defcustom undo-fu-session-make-file-name-function 'undo-fu-session-make-file-name
   "The function that computes the session file-path for the current buffer.
-The function takes two arguments (filepath, extension).
+The function takes two arguments (path, extension).
 The returned path must use the extension argument."
   :type 'function)
 
@@ -118,14 +119,14 @@ The returned path must use the extension argument."
 
 (defcustom undo-fu-session-temp-directories
   (cond
-   ((memq system-type '(ms-dos windows-nt))
+   ((memq system-type (list 'ms-dos 'windows-nt))
     (list))
    (t
     (list "/tmp" "/dev/shm")))
   "Temporary directories (must be absolute).
 
 Used by `undo-fu-session-ignore-temp-files' for directories to consider temporary."
-  :type '(repeat directory))
+  :type '(repeat string))
 
 (defcustom undo-fu-session-compression 'gz
   "The type of compression to use or nil.
@@ -152,7 +153,7 @@ to convert existing files to the newly selected format."
   "Number of files to store, nil to disable limiting entirely.
 
 Enforcing removes the oldest files."
-  :type '(choice (const :tag "Unlimited" nil) natnum))
+  :type 'integer)
 
 
 ;; ---------------------------------------------------------------------------
@@ -173,7 +174,7 @@ This is done without adjusting trailing slashes or following links."
   ;; or be relative to the default directory.
   ;;
   ;; Notes:
-  ;; - This is loosely based on `f-same?' from the `f' library.
+  ;; - This is loosely based on `f-same?'` from the `f' library.
   ;;   However it's important this only runs on the user directory and NOT trusted directories
   ;;   since there should never be any ambiguity (which could be caused by expansion)
   ;;   regarding which path is trusted.
@@ -209,7 +210,7 @@ ignoring all branches that aren't included in the current undo state."
                ;; Collapse all redo branches (giving the same results as if running `undo-only')
                (while (setq undo-list-next (gethash undo-list equiv-table))
                  (setq undo-list undo-list-next))
-               (and undo-list (null (eq t undo-list))))
+               (and undo-list (not (eq t undo-list))))
 
         ;; Pop all steps until the next boundary 'nil'.
         (let ((undo-elt t))
@@ -220,12 +221,12 @@ ignoring all branches that aren't included in the current undo state."
       (setq linear-list (cdr linear-list)))
 
     ;; Pass through 'nil', when there is no undo information.
-    ;; Also convert '(nil)' to 'nil', since this is no undo info too.
+    ;; Also convert '(list nil)' to 'nil', since this is no undo info too.
     ;;
     ;; Note that we use 'nil' as this is what `buffer-undo-list' is set
     ;; to when there are no undo steps yet.
     (cond
-     ((and linear-list (null (equal '(nil) linear-list)))
+     ((and linear-list (not (equal (list nil) linear-list)))
       linear-list)
      (t
       nil))))
@@ -234,7 +235,7 @@ ignoring all branches that aren't included in the current undo state."
 ;; Undo Encode/Decode Functionality
 
 (defun undo-fu-session--walk-tree (fn tree)
-  "Operate recursively on undo-list, calling FN on each element of TREE."
+  "Operate recursively on undo-list, calling FN TREE."
   (declare (important-return-value t))
   (cond
    ((consp tree)
@@ -339,7 +340,7 @@ ignoring all branches that aren't included in the current undo state."
 (defun undo-fu-session--next-step (list)
   "Get the next undo step in LIST.
 
-Argument LIST is a `buffer-undo-list' compatible list."
+Argument LIST compatible list `buffer-undo-list'."
   (declare (important-return-value t) (side-effect-free error-free))
   (while (car list)
     (setq list (cdr list)))
@@ -348,7 +349,7 @@ Argument LIST is a `buffer-undo-list' compatible list."
   list)
 
 (defun undo-fu-session--list-to-index-map (list index index-step step-to-index-hash)
-  "Populate the STEP-TO-INDEX-HASH with LIST elements.
+  "Populate the STEP-TO-INDEX-HASH with LIST element.
 
 List elements are used as keys mapping to INDEX by INDEX-STEP."
   (declare (important-return-value nil))
@@ -361,7 +362,7 @@ List elements are used as keys mapping to INDEX by INDEX-STEP."
 (defun undo-fu-session--list-from-index-map (list index index-step step-from-index-hash)
   "Populate the STEP-FROM-INDEX-HASH with INDEX by INDEX-STEP.
 
-Indices are used as keys mapping to LIST elements."
+INDEX-STEP are used as keys mapping to LIST elements."
   (declare (important-return-value nil))
   (unless (eq list t)
     (while list
@@ -371,8 +372,8 @@ Indices are used as keys mapping to LIST elements."
 
 (defun undo-fu-session--equivtable-encode (equiv-table buffer-list pending-list)
   "Convert the EQUIV-TABLE into an alist of buffer list indices.
-Argument BUFFER-LIST is typically `buffer-undo-list'.
-Argument PENDING-LIST is typically `pending-undo-list'."
+Argument BUFFER-LIST typically `undo-buffer-list'.
+Argument PENDING-LIST typically `pending-undo-list'."
   (declare (important-return-value t) (side-effect-free error-free))
 
   ;; Map undo-elem -> index.
@@ -385,22 +386,23 @@ Argument PENDING-LIST is typically `pending-undo-list'."
 
     (maphash
      (lambda (key val)
-       (when-let* ((key-num (gethash key step-to-index-hash))
-                   (val-num
-                    (cond
-                     ((eq t val)
-                      t)
-                     (t
-                      (gethash val step-to-index-hash)))))
-         (push (cons key-num val-num) equiv-table-alist)))
+       (let ((key-num (gethash key step-to-index-hash))
+             (val-num
+              (cond
+               ((eq t val)
+                t)
+               (t
+                (gethash val step-to-index-hash)))))
+         (when (and key-num val-num)
+           (push (cons key-num val-num) equiv-table-alist))))
      equiv-table)
     equiv-table-alist))
 
 
 (defun undo-fu-session--equivtable-decode (equiv-table-alist buffer-list pending-list)
   "Convert EQUIV-TABLE-ALIST into a hash compatible with `undo-equiv-table'.
-Argument BUFFER-LIST a `buffer-undo-list' compatible list.
-Argument PENDING-LIST a `pending-undo-list' compatible list."
+Argument BUFFER-LIST an `undo-buffer-list' compatible list.
+Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
   (let* ((equiv-table-length (length equiv-table-alist))
@@ -433,7 +435,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   ;; While errors are highly unlikely in this case,
   ;; clearing old files should _never_ interfere with other operations,
-  ;; so surround with an error check & message.
+  ;; so surround with error a check & error message.
   (condition-case err-1
       (when (file-directory-p undo-fu-session-directory)
         (dolist (file-with-attrs
@@ -494,7 +496,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
       (dolist (file-src-full files-to-convert)
         (let ((file-dst-full (file-name-with-extension file-src-full ext-dst)))
           (message "File %d of %d: %s"
-                   (1+ count-complete)
+                   count-complete
                    count-pending
                    (file-name-nondirectory file-dst-full))
           (condition-case-unless-debug err
@@ -504,7 +506,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
                   ;; Don't create lock-files for the following reasons:
                   ;; - The file name may be too long and fail to lock (see #10).
                   ;; - Locking is already handled by saving the file from which this undo-data
-                  ;;   is created so locking the undo-data is of limited use.
+                  ;;   is created so locking the undo-data if of limited use.
                   ;; - Small but unnecessary overhead.
                   ;;
                   ;; Having said this, there is a theoretical possibility two emacs instances
@@ -513,7 +515,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
                   ;; so there is practically no benefit in writing a file that is "correct" with
                   ;; respect to locking, when the undo-data doesn't match the file contents.
                   ;; In summary, we would either have to lock both files at once, or locking
-                  ;; when writing undo data is close to useless.
+                  ;; when writing undo data close to useless.
                   (let ((create-lockfiles nil))
                     (write-region nil nil file-dst-full nil 0)))
 
@@ -540,8 +542,11 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
   (cond
-   (undo-fu-session-compression
+   ((symbolp undo-fu-session-compression)
     (concat "." (symbol-name undo-fu-session-compression)))
+   ((eq undo-fu-session-compression t)
+    ;; Used for older versions where compression was a boolean.
+    ".gz")
    (t
     ".el")))
 
@@ -557,16 +562,16 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
                 undo-fu-session-make-file-name-function)
        (undo-fu-session-make-file-name filename ext)))))
 
-(defun undo-fu-session-make-file-name (filepath ext)
-  "Take the path FILEPATH and EXT, returning a name based on them."
+(defun undo-fu-session-make-file-name (filename ext)
+  "Take the path FILENAME, EXT and return a name base on this."
   (declare (important-return-value t) (side-effect-free error-free))
   (concat
    (file-name-concat undo-fu-session-directory
-                     (url-hexify-string (convert-standard-filename (expand-file-name filepath))))
+                     (url-hexify-string (convert-standard-filename (expand-file-name filename))))
    ext))
 
 (defun undo-fu-session--match-file-name (filename test-files)
-  "Return t if FILENAME matches any item in TEST-FILES."
+  "Return t if FILENAME match any item in TEST-FILES."
   (declare (important-return-value t))
   ;; NOTE: can't be `side-effect-free' because it calls a user defined callback.
   (let ((case-fold-search (file-name-case-insensitive-p filename))
@@ -584,7 +589,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
     found))
 
 (defun undo-fu-session--match-major-mode (mode test-modes)
-  "Return t if MODE matches any item in TEST-MODES."
+  "Return t if MODE match any item in TEST-MODES."
   (declare (important-return-value t) (side-effect-free error-free))
   (let ((found nil))
     (while mode
@@ -628,7 +633,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   (unless (file-directory-p undo-fu-session-directory)
     (make-directory undo-fu-session-directory t)
-    ;; These files should only be readable by the owner, see #2.
+    ;; These files should only readable by the owner, see #2.
     ;; Setting the executable bit is important for directories to be writable.
     (set-file-modes undo-fu-session-directory #o700)))
 
@@ -642,7 +647,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
      ((null filename)
       nil)
      ((and undo-fu-session-ignore-encrypted-files
-           (bound-and-true-p epa-file-handler)
+           epa-file-handler
            (string-match-p (car epa-file-handler) filename))
       nil)
      ((and undo-fu-session-ignore-temp-files (undo-fu-session--temp-file-check filename))
@@ -771,7 +776,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
           (setq content-header (read (current-buffer)))
 
           ;; Use `undo-fu-session--message-without-echo' to avoid distracting the user
-          ;; when a commonplace reason for failing to load is hit.
+          ;; when a common-place reason for failing to load is hit.
           ;;
           ;; These issues are common when working with others on documents.
           ;; This way users may find out why undo didn't load if they need,
@@ -816,8 +821,8 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
         ;; Assign undo data to the current buffer.
         (setq buffer-undo-list emacs-buffer-undo-list)
         (setq pending-undo-list emacs-pending-undo-list)
-        ;; Merge the hash-table since this is a global variable shared between
-        ;; buffers; otherwise this interferes with other buffers' undo-only/redo.
+        ;; Merge the hash-table since this is a global-variable, share between
+        ;; buffers otherwise this interferes with other buffers undo-only/redo.
         (when (hash-table-p emacs-undo-equiv-table)
           (maphash (lambda (key val) (puthash key val undo-equiv-table)) emacs-undo-equiv-table))
         t))))
@@ -865,7 +870,7 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
 
 (defun undo-fu-session--mode-in-any-buffer ()
   "Return non-nil if the `undo-fu-session-mode' is enabled in any buffer."
-  (declare (important-return-value t) (side-effect-free error-free))
+  (declare (side-effect-free error-free))
   (let ((mode-in-any-buffer nil)
         (buffers (buffer-list)))
     (while buffers
@@ -899,10 +904,10 @@ Argument PENDING-LIST a `pending-undo-list' compatible list."
          ;; Not already enabled.
          (not (bound-and-true-p undo-fu-session-mode))
          ;; Not in the mini-buffer.
-         (null (minibufferp))
-         ;; Not a special mode (package list, tabulated data, etc.)
+         (not (minibufferp))
+         ;; Not a special mode (package list, tabulated data ... etc)
          ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
-         (null (derived-mode-p 'special-mode)))
+         (not (derived-mode-p 'special-mode)))
     (undo-fu-session-mode 1)))
 
 ;;;###autoload
